@@ -54,9 +54,7 @@ ICON_ONLINE = ""
 ICON_OFFLINE = "network-offline-symbolic"
 ICON_UNREACHABLE = "network-error-symbolic"
 
-INHIBIT_STATES = (OpStatus.CALCULATING,
-                  OpStatus.WAITING_PERMISSION,
-                  OpStatus.TRANSFERRING,
+INHIBIT_STATES = (OpStatus.TRANSFERRING,
                   OpStatus.PAUSED)
 
 ALL_BUTTONS = ("transfer_accept", \
@@ -447,6 +445,7 @@ class OverviewButton(GObject.Object):
 class WarpWindow(GObject.Object):
     __gsignals__ = {
         'exit': (GObject.SignalFlags.RUN_LAST, None, ()),
+        'restart': (GObject.SignalFlags.RUN_LAST, None, ())
     }
 
     def __init__(self):
@@ -565,11 +564,20 @@ class WarpWindow(GObject.Object):
         item.connect("activate", self.on_open_location_clicked)
         menu.add(item)
 
+        menu.add(Gtk.SeparatorMenuItem(visible=True))
+
         item = Gtk.MenuItem(label=_("Connect manually"), sensitive=False)
         item.connect("activate", self.manual_connect)
         menu.add(item)
         self.manual_connect_menu_item = item
 
+        item = Gtk.MenuItem(label=_("Restart service"), sensitive=False)
+        item.connect("activate", self.restart_service_clicked)
+        menu.add(item)
+        self.restart_service_menu_item = item
+
+        menu.add(Gtk.SeparatorMenuItem(visible=True))
+
         item = Gtk.MenuItem(label=_("Preferences"))
         item.connect("activate", self.open_preferences)
         menu.add(item)
@@ -831,14 +839,16 @@ class WarpWindow(GObject.Object):
         self.connect_dialog = ManualConnectDialog(self)
         self.connect_dialog.show()
 
+    def restart_service_clicked(self, menuitem):
+        self.emit("restart")
+        self.restart_service_menu_item.set_sensitive(False)
+
     @GObject.Signal(arg_types=(str,))
     def manual_connect_to_host(self, host):
         logging.debug("Connecting to " + host)
 
     def report_bad_save_folder(self):
         path = prefs.get_save_path()
-        if path.startswith("/run/user"):
-            path = os.path.basename(path)
         self.bad_save_folder_label.set_text(path)
         self.show_page("bad-save-folder")
 
@@ -918,6 +928,8 @@ class WarpWindow(GObject.Object):
             self.prefs_window.destroy()
             self.prefs_window = None
 
+        self.manual_connect_menu_item.set_sensitive(False)
+
         self.show_page("restart")
 
     def update_restart_dialog_status(self, active_ops):
@@ -951,6 +963,8 @@ class WarpWindow(GObject.Object):
             GLib.source_remove(self.server_start_timeout_id)
             self.server_start_timeout_id = 0
 
+        self.restart_service_menu_item.set_sensitive(True)
+
         self.start_discovery_timer()
 
     def start_discovery_timer(self):
@@ -1329,6 +1343,7 @@ class WarpApplication(Gtk.Application):
 
         self.window = WarpWindow()
         self.window.connect("exit", lambda w: self.exit_warp())
+        self.window.connect("restart", lambda w: self.new_server())
         self.window.connect("manual_connect_to_host", lambda _, host: self.server.register_with_host(host))
 
         self.add_window(self.window.window)
@@ -1737,7 +1752,7 @@ class WarpApplication(Gtk.Application):
         self.window.toggle_visibility(time)
 
 
-def main():
+def main(testing=False):
     import signal
 
     try:
@@ -1746,7 +1761,7 @@ def main():
         pass
 
     try:
-        w = WarpApplication(testing=False)
+        w = WarpApplication(testing)
         signal.signal(signal.SIGINT, lambda s, f: w.exit_warp())
         signal.signal(signal.SIGTERM, lambda s, f: w.exit_warp())
 
